"""
Example Alembic env.py showing how to integrate alembic-pg-enum-generator.
"""

from logging.config import fileConfig

from alembic import context

# Import your models
from models import Base
from sqlalchemy import engine_from_config, pool

# IMPORTANT: Import alembic-pg-enum-generator to register hooks
import alembic_pg_enum_generator

# Optional: Configure enum filtering
config = alembic_pg_enum_generator.Config(
    # Only process enums with specific naming patterns
    include_name=lambda name: name.endswith("_status")
)
alembic_pg_enum_generator.set_configuration(config)

# This is the Alembic Config object
config = context.config

# Set up logging
if config.config_file_name is not None:
    fileConfig(config.config_file_name)

# Set the target metadata for autogenerate support
target_metadata = Base.metadata


def run_migrations_offline() -> None:
    """Run migrations in 'offline' mode."""
    url = config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online() -> None:
    """Run migrations in 'online' mode."""
    connectable = engine_from_config(
        config.get_section(config.config_ini_section),
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(connection=connection, target_metadata=target_metadata)

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()
